@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0701';
 
 use Carp;
 use List::Util qw( first );
@@ -138,6 +138,11 @@ sub step {
 
     my $note = Music::Note->new( $name, $self->note_format );
     my $num  = $note->format('midinum');
+
+    warn sprintf "Given note: %s, ISO: %s, Formatted: %d\n",
+        $name, $note->format('ISO'), $num
+        if $self->verbose;
+
     $num += $steps;
     $note = Music::Note->new( $num, 'midinum' );
 
@@ -145,6 +150,10 @@ sub step {
         $note->en_eq('flat');
     }
 
+    warn sprintf "\tNew steps: %d, ISO: %s, Formatted: %s\n",
+        $steps, $note->format('ISO'), $note->format( $self->note_format )
+        if $self->verbose;
+
     return $note;
 }
 
@@ -162,7 +171,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0700
+version 0.0701
 
 =head1 SYNOPSIS
 
